# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: steammessages_econ.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import service as _service
from google.protobuf import service_reflection
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import steam.protobufs.steammessages_base_pb2 as steammessages__base__pb2
import steam.protobufs.steammessages_unified_base_pb2 as steammessages__unified__base__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='steammessages_econ.proto',
  package='',
  syntax='proto2',
  serialized_options=b'\220\001\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x18steammessages_econ.proto\x1a\x18steammessages_base.proto\x1a steammessages_unified_base.proto\"\x95\x03\n/CEcon_GetInventoryItemsWithDescriptions_Request\x12\x0f\n\x07steamid\x18\x01 \x01(\x06\x12\r\n\x05\x61ppid\x18\x02 \x01(\r\x12\x11\n\tcontextid\x18\x03 \x01(\x04\x12\x18\n\x10get_descriptions\x18\x04 \x01(\x08\x12$\n\x1c\x66or_trade_offer_verification\x18\n \x01(\x08\x12\x10\n\x08language\x18\x05 \x01(\t\x12O\n\x07\x66ilters\x18\x06 \x01(\x0b\x32>.CEcon_GetInventoryItemsWithDescriptions_Request.FilterOptions\x12\x15\n\rstart_assetid\x18\x08 \x01(\x04\x12\r\n\x05\x63ount\x18\t \x01(\x05\x1a\x66\n\rFilterOptions\x12\x10\n\x08\x61ssetids\x18\x01 \x03(\x04\x12\x13\n\x0b\x63urrencyids\x18\x02 \x03(\r\x12\x15\n\rtradable_only\x18\x03 \x01(\x08\x12\x17\n\x0fmarketable_only\x18\x04 \x01(\x08\"\xe7\x01\n\x0b\x43\x45\x63on_Asset\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\x11\n\tcontextid\x18\x02 \x01(\x04\x12\x0f\n\x07\x61ssetid\x18\x03 \x01(\x04\x12\x0f\n\x07\x63lassid\x18\x04 \x01(\x04\x12\x12\n\ninstanceid\x18\x05 \x01(\x04\x12N\n\ncurrencyid\x18\x06 \x01(\rB:\x82\xb5\x18\x36Set currencyid if it\'s a currency, assetid for an item\x12\x0e\n\x06\x61mount\x18\x07 \x01(\x03\x12\x0f\n\x07missing\x18\x08 \x01(\x08\x12\x0f\n\x07\x65st_usd\x18\t \x01(\x03\"V\n\x19\x43\x45\x63onItem_DescriptionLine\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\x12\r\n\x05\x63olor\x18\x03 \x01(\t\x12\r\n\x05label\x18\x04 \x01(\t\".\n\x10\x43\x45\x63onItem_Action\x12\x0c\n\x04link\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\xe3\x06\n\x15\x43\x45\x63onItem_Description\x12\r\n\x05\x61ppid\x18\x01 \x01(\x05\x12\x0f\n\x07\x63lassid\x18\x02 \x01(\x04\x12\x12\n\ninstanceid\x18\x03 \x01(\x04\x12\x10\n\x08\x63urrency\x18\x04 \x01(\x08\x12\x18\n\x10\x62\x61\x63kground_color\x18\x05 \x01(\t\x12\x10\n\x08icon_url\x18\x06 \x01(\t\x12\x16\n\x0eicon_url_large\x18\x07 \x01(\t\x12\x30\n\x0c\x64\x65scriptions\x18\x08 \x03(\x0b\x32\x1a.CEconItem_DescriptionLine\x12\x10\n\x08tradable\x18\t \x01(\x08\x12\"\n\x07\x61\x63tions\x18\n \x03(\x0b\x32\x11.CEconItem_Action\x12\x36\n\x12owner_descriptions\x18\x0b \x03(\x0b\x32\x1a.CEconItem_DescriptionLine\x12(\n\rowner_actions\x18\x0c \x03(\x0b\x32\x11.CEconItem_Action\x12\x15\n\rfraudwarnings\x18\r \x03(\t\x12\x0c\n\x04name\x18\x0e \x01(\t\x12\x12\n\nname_color\x18\x0f \x01(\t\x12\x0c\n\x04type\x18\x10 \x01(\t\x12\x13\n\x0bmarket_name\x18\x11 \x01(\t\x12\x18\n\x10market_hash_name\x18\x12 \x01(\t\x12\x12\n\nmarket_fee\x18\x13 \x01(\t\x12\x16\n\x0emarket_fee_app\x18\x1c \x01(\x05\x12.\n\x0e\x63ontained_item\x18\x14 \x01(\x0b\x32\x16.CEconItem_Description\x12)\n\x0emarket_actions\x18\x15 \x03(\x0b\x32\x11.CEconItem_Action\x12\x11\n\tcommodity\x18\x16 \x01(\x08\x12#\n\x1bmarket_tradable_restriction\x18\x17 \x01(\x05\x12%\n\x1dmarket_marketable_restriction\x18\x18 \x01(\x05\x12\x12\n\nmarketable\x18\x19 \x01(\x08\x12\x1c\n\x04tags\x18\x1a \x03(\x0b\x32\x0e.CEconItem_Tag\x12\x17\n\x0fitem_expiration\x18\x1b \x01(\t\x12&\n\x1emarket_buy_country_restriction\x18\x1e \x01(\t\x12\'\n\x1fmarket_sell_country_restriction\x18\x1f \x01(\t\"\x98\x03\n\rCEconItem_Tag\x12\x31\n\x05\x61ppid\x18\x01 \x01(\rB\"\x82\xb5\x18\x1eThe app that contains the item\x12J\n\x08\x63\x61tegory\x18\x02 \x01(\tB8\x82\xb5\x18\x34The internal name of the category the tag belongs to\x12\x37\n\rinternal_name\x18\x03 \x01(\tB \x82\xb5\x18\x1cThe internal name of the tag\x12G\n\x17localized_category_name\x18\x04 \x01(\tB&\x82\xb5\x18\"The localized name of the category\x12=\n\x12localized_tag_name\x18\x05 \x01(\tB!\x82\xb5\x18\x1dThe localized name of the tag\x12G\n\x05\x63olor\x18\x06 \x01(\tB8\x82\xb5\x18\x34The color to use when displaying the tag to the user\"\xc4\x02\n0CEcon_GetInventoryItemsWithDescriptions_Response\x12\x1c\n\x06\x61ssets\x18\x01 \x03(\x0b\x32\x0c.CEcon_Asset\x12,\n\x0c\x64\x65scriptions\x18\x02 \x03(\x0b\x32\x16.CEconItem_Description\x12{\n\x0emissing_assets\x18\x03 \x03(\x0b\x32\x0c.CEcon_AssetBU\x82\xb5\x18QThis list of assets in the original list we could not find in the users inventory\x12\x12\n\nmore_items\x18\x04 \x01(\x08\x12\x14\n\x0clast_assetid\x18\x05 \x01(\x04\x12\x1d\n\x15total_inventory_count\x18\x06 \x01(\r\"D\n&CEcon_GetTradeOfferAccessToken_Request\x12\x1a\n\x12generate_new_token\x18\x01 \x01(\x08\"K\n\'CEcon_GetTradeOfferAccessToken_Response\x12 \n\x18trade_offer_access_token\x18\x01 \x01(\t\"C\n-CEcon_ClientGetItemShopOverlayAuthURL_Request\x12\x12\n\nreturn_url\x18\x01 \x01(\t\"=\n.CEcon_ClientGetItemShopOverlayAuthURL_Response\x12\x0b\n\x03url\x18\x01 \x01(\t\"\xa9\x01\n\x1f\x43\x45\x63on_GetAssetClassInfo_Request\x12\x10\n\x08language\x18\x01 \x01(\t\x12\r\n\x05\x61ppid\x18\x02 \x01(\r\x12\x37\n\x07\x63lasses\x18\x03 \x03(\x0b\x32&.CEcon_GetAssetClassInfo_Request.Class\x1a,\n\x05\x43lass\x12\x0f\n\x07\x63lassid\x18\x01 \x01(\x04\x12\x12\n\ninstanceid\x18\x02 \x01(\x04\"P\n CEcon_GetAssetClassInfo_Response\x12,\n\x0c\x64\x65scriptions\x18\x01 \x03(\x0b\x32\x16.CEconItem_Description2\xb6\x06\n\x04\x45\x63on\x12\xd1\x01\n!GetInventoryItemsWithDescriptions\x12\x30.CEcon_GetInventoryItemsWithDescriptions_Request\x1a\x31.CEcon_GetInventoryItemsWithDescriptions_Response\"G\x82\xb5\x18\x43Gets a set of items from a users inventory, along with descriptions\x12\x9a\x01\n\x18GetTradeOfferAccessToken\x12\'.CEcon_GetTradeOfferAccessToken_Request\x1a(.CEcon_GetTradeOfferAccessToken_Response\"+\x82\xb5\x18\'Get the user\'s trade offer access token\x12\xd9\x01\n\x1f\x43lientGetItemShopOverlayAuthURL\x12..CEcon_ClientGetItemShopOverlayAuthURL_Request\x1a/.CEcon_ClientGetItemShopOverlayAuthURL_Response\"U\x82\xb5\x18QGenerates a URL which sets a secure cookie for in-game-browser itemshop purchases\x12\x9f\x01\n\x11GetAssetClassInfo\x12 .CEcon_GetAssetClassInfo_Request\x1a!.CEcon_GetAssetClassInfo_Response\"E\x82\xb5\x18\x41Returns description information about the passed in asset classes\x1a?\x82\xb5\x18;A service that provides communication with the econ serversB\x03\x90\x01\x01'
  ,
  dependencies=[steammessages__base__pb2.DESCRIPTOR,steammessages__unified__base__pb2.DESCRIPTOR,])




_CECON_GETINVENTORYITEMSWITHDESCRIPTIONS_REQUEST_FILTEROPTIONS = _descriptor.Descriptor(
  name='FilterOptions',
  full_name='CEcon_GetInventoryItemsWithDescriptions_Request.FilterOptions',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='assetids', full_name='CEcon_GetInventoryItemsWithDescriptions_Request.FilterOptions.assetids', index=0,
      number=1, type=4, cpp_type=4, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='currencyids', full_name='CEcon_GetInventoryItemsWithDescriptions_Request.FilterOptions.currencyids', index=1,
      number=2, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tradable_only', full_name='CEcon_GetInventoryItemsWithDescriptions_Request.FilterOptions.tradable_only', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='marketable_only', full_name='CEcon_GetInventoryItemsWithDescriptions_Request.FilterOptions.marketable_only', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=392,
  serialized_end=494,
)

_CECON_GETINVENTORYITEMSWITHDESCRIPTIONS_REQUEST = _descriptor.Descriptor(
  name='CEcon_GetInventoryItemsWithDescriptions_Request',
  full_name='CEcon_GetInventoryItemsWithDescriptions_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='steamid', full_name='CEcon_GetInventoryItemsWithDescriptions_Request.steamid', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='appid', full_name='CEcon_GetInventoryItemsWithDescriptions_Request.appid', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='contextid', full_name='CEcon_GetInventoryItemsWithDescriptions_Request.contextid', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='get_descriptions', full_name='CEcon_GetInventoryItemsWithDescriptions_Request.get_descriptions', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='for_trade_offer_verification', full_name='CEcon_GetInventoryItemsWithDescriptions_Request.for_trade_offer_verification', index=4,
      number=10, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='language', full_name='CEcon_GetInventoryItemsWithDescriptions_Request.language', index=5,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='filters', full_name='CEcon_GetInventoryItemsWithDescriptions_Request.filters', index=6,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='start_assetid', full_name='CEcon_GetInventoryItemsWithDescriptions_Request.start_assetid', index=7,
      number=8, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='count', full_name='CEcon_GetInventoryItemsWithDescriptions_Request.count', index=8,
      number=9, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CECON_GETINVENTORYITEMSWITHDESCRIPTIONS_REQUEST_FILTEROPTIONS, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=89,
  serialized_end=494,
)


_CECON_ASSET = _descriptor.Descriptor(
  name='CEcon_Asset',
  full_name='CEcon_Asset',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='appid', full_name='CEcon_Asset.appid', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='contextid', full_name='CEcon_Asset.contextid', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='assetid', full_name='CEcon_Asset.assetid', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='classid', full_name='CEcon_Asset.classid', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='instanceid', full_name='CEcon_Asset.instanceid', index=4,
      number=5, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='currencyid', full_name='CEcon_Asset.currencyid', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\0306Set currencyid if it\'s a currency, assetid for an item', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='amount', full_name='CEcon_Asset.amount', index=6,
      number=7, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='missing', full_name='CEcon_Asset.missing', index=7,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='est_usd', full_name='CEcon_Asset.est_usd', index=8,
      number=9, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=497,
  serialized_end=728,
)


_CECONITEM_DESCRIPTIONLINE = _descriptor.Descriptor(
  name='CEconItem_DescriptionLine',
  full_name='CEconItem_DescriptionLine',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='CEconItem_DescriptionLine.type', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='CEconItem_DescriptionLine.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='color', full_name='CEconItem_DescriptionLine.color', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='label', full_name='CEconItem_DescriptionLine.label', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=730,
  serialized_end=816,
)


_CECONITEM_ACTION = _descriptor.Descriptor(
  name='CEconItem_Action',
  full_name='CEconItem_Action',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='link', full_name='CEconItem_Action.link', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='CEconItem_Action.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=818,
  serialized_end=864,
)


_CECONITEM_DESCRIPTION = _descriptor.Descriptor(
  name='CEconItem_Description',
  full_name='CEconItem_Description',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='appid', full_name='CEconItem_Description.appid', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='classid', full_name='CEconItem_Description.classid', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='instanceid', full_name='CEconItem_Description.instanceid', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='currency', full_name='CEconItem_Description.currency', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='background_color', full_name='CEconItem_Description.background_color', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='icon_url', full_name='CEconItem_Description.icon_url', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='icon_url_large', full_name='CEconItem_Description.icon_url_large', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='descriptions', full_name='CEconItem_Description.descriptions', index=7,
      number=8, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tradable', full_name='CEconItem_Description.tradable', index=8,
      number=9, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='actions', full_name='CEconItem_Description.actions', index=9,
      number=10, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='owner_descriptions', full_name='CEconItem_Description.owner_descriptions', index=10,
      number=11, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='owner_actions', full_name='CEconItem_Description.owner_actions', index=11,
      number=12, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fraudwarnings', full_name='CEconItem_Description.fraudwarnings', index=12,
      number=13, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='CEconItem_Description.name', index=13,
      number=14, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name_color', full_name='CEconItem_Description.name_color', index=14,
      number=15, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='CEconItem_Description.type', index=15,
      number=16, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='market_name', full_name='CEconItem_Description.market_name', index=16,
      number=17, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='market_hash_name', full_name='CEconItem_Description.market_hash_name', index=17,
      number=18, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='market_fee', full_name='CEconItem_Description.market_fee', index=18,
      number=19, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='market_fee_app', full_name='CEconItem_Description.market_fee_app', index=19,
      number=28, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='contained_item', full_name='CEconItem_Description.contained_item', index=20,
      number=20, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='market_actions', full_name='CEconItem_Description.market_actions', index=21,
      number=21, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='commodity', full_name='CEconItem_Description.commodity', index=22,
      number=22, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='market_tradable_restriction', full_name='CEconItem_Description.market_tradable_restriction', index=23,
      number=23, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='market_marketable_restriction', full_name='CEconItem_Description.market_marketable_restriction', index=24,
      number=24, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='marketable', full_name='CEconItem_Description.marketable', index=25,
      number=25, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tags', full_name='CEconItem_Description.tags', index=26,
      number=26, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='item_expiration', full_name='CEconItem_Description.item_expiration', index=27,
      number=27, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='market_buy_country_restriction', full_name='CEconItem_Description.market_buy_country_restriction', index=28,
      number=30, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='market_sell_country_restriction', full_name='CEconItem_Description.market_sell_country_restriction', index=29,
      number=31, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=867,
  serialized_end=1734,
)


_CECONITEM_TAG = _descriptor.Descriptor(
  name='CEconItem_Tag',
  full_name='CEconItem_Tag',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='appid', full_name='CEconItem_Tag.appid', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\036The app that contains the item', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='category', full_name='CEconItem_Tag.category', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\0304The internal name of the category the tag belongs to', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='internal_name', full_name='CEconItem_Tag.internal_name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\034The internal name of the tag', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='localized_category_name', full_name='CEconItem_Tag.localized_category_name', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\"The localized name of the category', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='localized_tag_name', full_name='CEconItem_Tag.localized_tag_name', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\035The localized name of the tag', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='color', full_name='CEconItem_Tag.color', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\0304The color to use when displaying the tag to the user', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1737,
  serialized_end=2145,
)


_CECON_GETINVENTORYITEMSWITHDESCRIPTIONS_RESPONSE = _descriptor.Descriptor(
  name='CEcon_GetInventoryItemsWithDescriptions_Response',
  full_name='CEcon_GetInventoryItemsWithDescriptions_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='assets', full_name='CEcon_GetInventoryItemsWithDescriptions_Response.assets', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='descriptions', full_name='CEcon_GetInventoryItemsWithDescriptions_Response.descriptions', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='missing_assets', full_name='CEcon_GetInventoryItemsWithDescriptions_Response.missing_assets', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030QThis list of assets in the original list we could not find in the users inventory', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='more_items', full_name='CEcon_GetInventoryItemsWithDescriptions_Response.more_items', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='last_assetid', full_name='CEcon_GetInventoryItemsWithDescriptions_Response.last_assetid', index=4,
      number=5, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='total_inventory_count', full_name='CEcon_GetInventoryItemsWithDescriptions_Response.total_inventory_count', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2148,
  serialized_end=2472,
)


_CECON_GETTRADEOFFERACCESSTOKEN_REQUEST = _descriptor.Descriptor(
  name='CEcon_GetTradeOfferAccessToken_Request',
  full_name='CEcon_GetTradeOfferAccessToken_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='generate_new_token', full_name='CEcon_GetTradeOfferAccessToken_Request.generate_new_token', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2474,
  serialized_end=2542,
)


_CECON_GETTRADEOFFERACCESSTOKEN_RESPONSE = _descriptor.Descriptor(
  name='CEcon_GetTradeOfferAccessToken_Response',
  full_name='CEcon_GetTradeOfferAccessToken_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='trade_offer_access_token', full_name='CEcon_GetTradeOfferAccessToken_Response.trade_offer_access_token', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2544,
  serialized_end=2619,
)


_CECON_CLIENTGETITEMSHOPOVERLAYAUTHURL_REQUEST = _descriptor.Descriptor(
  name='CEcon_ClientGetItemShopOverlayAuthURL_Request',
  full_name='CEcon_ClientGetItemShopOverlayAuthURL_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='return_url', full_name='CEcon_ClientGetItemShopOverlayAuthURL_Request.return_url', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2621,
  serialized_end=2688,
)


_CECON_CLIENTGETITEMSHOPOVERLAYAUTHURL_RESPONSE = _descriptor.Descriptor(
  name='CEcon_ClientGetItemShopOverlayAuthURL_Response',
  full_name='CEcon_ClientGetItemShopOverlayAuthURL_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='url', full_name='CEcon_ClientGetItemShopOverlayAuthURL_Response.url', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2690,
  serialized_end=2751,
)


_CECON_GETASSETCLASSINFO_REQUEST_CLASS = _descriptor.Descriptor(
  name='Class',
  full_name='CEcon_GetAssetClassInfo_Request.Class',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='classid', full_name='CEcon_GetAssetClassInfo_Request.Class.classid', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='instanceid', full_name='CEcon_GetAssetClassInfo_Request.Class.instanceid', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2879,
  serialized_end=2923,
)

_CECON_GETASSETCLASSINFO_REQUEST = _descriptor.Descriptor(
  name='CEcon_GetAssetClassInfo_Request',
  full_name='CEcon_GetAssetClassInfo_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='language', full_name='CEcon_GetAssetClassInfo_Request.language', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='appid', full_name='CEcon_GetAssetClassInfo_Request.appid', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='classes', full_name='CEcon_GetAssetClassInfo_Request.classes', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CECON_GETASSETCLASSINFO_REQUEST_CLASS, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2754,
  serialized_end=2923,
)


_CECON_GETASSETCLASSINFO_RESPONSE = _descriptor.Descriptor(
  name='CEcon_GetAssetClassInfo_Response',
  full_name='CEcon_GetAssetClassInfo_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='descriptions', full_name='CEcon_GetAssetClassInfo_Response.descriptions', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2925,
  serialized_end=3005,
)

_CECON_GETINVENTORYITEMSWITHDESCRIPTIONS_REQUEST_FILTEROPTIONS.containing_type = _CECON_GETINVENTORYITEMSWITHDESCRIPTIONS_REQUEST
_CECON_GETINVENTORYITEMSWITHDESCRIPTIONS_REQUEST.fields_by_name['filters'].message_type = _CECON_GETINVENTORYITEMSWITHDESCRIPTIONS_REQUEST_FILTEROPTIONS
_CECONITEM_DESCRIPTION.fields_by_name['descriptions'].message_type = _CECONITEM_DESCRIPTIONLINE
_CECONITEM_DESCRIPTION.fields_by_name['actions'].message_type = _CECONITEM_ACTION
_CECONITEM_DESCRIPTION.fields_by_name['owner_descriptions'].message_type = _CECONITEM_DESCRIPTIONLINE
_CECONITEM_DESCRIPTION.fields_by_name['owner_actions'].message_type = _CECONITEM_ACTION
_CECONITEM_DESCRIPTION.fields_by_name['contained_item'].message_type = _CECONITEM_DESCRIPTION
_CECONITEM_DESCRIPTION.fields_by_name['market_actions'].message_type = _CECONITEM_ACTION
_CECONITEM_DESCRIPTION.fields_by_name['tags'].message_type = _CECONITEM_TAG
_CECON_GETINVENTORYITEMSWITHDESCRIPTIONS_RESPONSE.fields_by_name['assets'].message_type = _CECON_ASSET
_CECON_GETINVENTORYITEMSWITHDESCRIPTIONS_RESPONSE.fields_by_name['descriptions'].message_type = _CECONITEM_DESCRIPTION
_CECON_GETINVENTORYITEMSWITHDESCRIPTIONS_RESPONSE.fields_by_name['missing_assets'].message_type = _CECON_ASSET
_CECON_GETASSETCLASSINFO_REQUEST_CLASS.containing_type = _CECON_GETASSETCLASSINFO_REQUEST
_CECON_GETASSETCLASSINFO_REQUEST.fields_by_name['classes'].message_type = _CECON_GETASSETCLASSINFO_REQUEST_CLASS
_CECON_GETASSETCLASSINFO_RESPONSE.fields_by_name['descriptions'].message_type = _CECONITEM_DESCRIPTION
DESCRIPTOR.message_types_by_name['CEcon_GetInventoryItemsWithDescriptions_Request'] = _CECON_GETINVENTORYITEMSWITHDESCRIPTIONS_REQUEST
DESCRIPTOR.message_types_by_name['CEcon_Asset'] = _CECON_ASSET
DESCRIPTOR.message_types_by_name['CEconItem_DescriptionLine'] = _CECONITEM_DESCRIPTIONLINE
DESCRIPTOR.message_types_by_name['CEconItem_Action'] = _CECONITEM_ACTION
DESCRIPTOR.message_types_by_name['CEconItem_Description'] = _CECONITEM_DESCRIPTION
DESCRIPTOR.message_types_by_name['CEconItem_Tag'] = _CECONITEM_TAG
DESCRIPTOR.message_types_by_name['CEcon_GetInventoryItemsWithDescriptions_Response'] = _CECON_GETINVENTORYITEMSWITHDESCRIPTIONS_RESPONSE
DESCRIPTOR.message_types_by_name['CEcon_GetTradeOfferAccessToken_Request'] = _CECON_GETTRADEOFFERACCESSTOKEN_REQUEST
DESCRIPTOR.message_types_by_name['CEcon_GetTradeOfferAccessToken_Response'] = _CECON_GETTRADEOFFERACCESSTOKEN_RESPONSE
DESCRIPTOR.message_types_by_name['CEcon_ClientGetItemShopOverlayAuthURL_Request'] = _CECON_CLIENTGETITEMSHOPOVERLAYAUTHURL_REQUEST
DESCRIPTOR.message_types_by_name['CEcon_ClientGetItemShopOverlayAuthURL_Response'] = _CECON_CLIENTGETITEMSHOPOVERLAYAUTHURL_RESPONSE
DESCRIPTOR.message_types_by_name['CEcon_GetAssetClassInfo_Request'] = _CECON_GETASSETCLASSINFO_REQUEST
DESCRIPTOR.message_types_by_name['CEcon_GetAssetClassInfo_Response'] = _CECON_GETASSETCLASSINFO_RESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CEcon_GetInventoryItemsWithDescriptions_Request = _reflection.GeneratedProtocolMessageType('CEcon_GetInventoryItemsWithDescriptions_Request', (_message.Message,), {

  'FilterOptions' : _reflection.GeneratedProtocolMessageType('FilterOptions', (_message.Message,), {
    'DESCRIPTOR' : _CECON_GETINVENTORYITEMSWITHDESCRIPTIONS_REQUEST_FILTEROPTIONS,
    '__module__' : 'steammessages_econ_pb2'
    # @@protoc_insertion_point(class_scope:CEcon_GetInventoryItemsWithDescriptions_Request.FilterOptions)
    })
  ,
  'DESCRIPTOR' : _CECON_GETINVENTORYITEMSWITHDESCRIPTIONS_REQUEST,
  '__module__' : 'steammessages_econ_pb2'
  # @@protoc_insertion_point(class_scope:CEcon_GetInventoryItemsWithDescriptions_Request)
  })
_sym_db.RegisterMessage(CEcon_GetInventoryItemsWithDescriptions_Request)
_sym_db.RegisterMessage(CEcon_GetInventoryItemsWithDescriptions_Request.FilterOptions)

CEcon_Asset = _reflection.GeneratedProtocolMessageType('CEcon_Asset', (_message.Message,), {
  'DESCRIPTOR' : _CECON_ASSET,
  '__module__' : 'steammessages_econ_pb2'
  # @@protoc_insertion_point(class_scope:CEcon_Asset)
  })
_sym_db.RegisterMessage(CEcon_Asset)

CEconItem_DescriptionLine = _reflection.GeneratedProtocolMessageType('CEconItem_DescriptionLine', (_message.Message,), {
  'DESCRIPTOR' : _CECONITEM_DESCRIPTIONLINE,
  '__module__' : 'steammessages_econ_pb2'
  # @@protoc_insertion_point(class_scope:CEconItem_DescriptionLine)
  })
_sym_db.RegisterMessage(CEconItem_DescriptionLine)

CEconItem_Action = _reflection.GeneratedProtocolMessageType('CEconItem_Action', (_message.Message,), {
  'DESCRIPTOR' : _CECONITEM_ACTION,
  '__module__' : 'steammessages_econ_pb2'
  # @@protoc_insertion_point(class_scope:CEconItem_Action)
  })
_sym_db.RegisterMessage(CEconItem_Action)

CEconItem_Description = _reflection.GeneratedProtocolMessageType('CEconItem_Description', (_message.Message,), {
  'DESCRIPTOR' : _CECONITEM_DESCRIPTION,
  '__module__' : 'steammessages_econ_pb2'
  # @@protoc_insertion_point(class_scope:CEconItem_Description)
  })
_sym_db.RegisterMessage(CEconItem_Description)

CEconItem_Tag = _reflection.GeneratedProtocolMessageType('CEconItem_Tag', (_message.Message,), {
  'DESCRIPTOR' : _CECONITEM_TAG,
  '__module__' : 'steammessages_econ_pb2'
  # @@protoc_insertion_point(class_scope:CEconItem_Tag)
  })
_sym_db.RegisterMessage(CEconItem_Tag)

CEcon_GetInventoryItemsWithDescriptions_Response = _reflection.GeneratedProtocolMessageType('CEcon_GetInventoryItemsWithDescriptions_Response', (_message.Message,), {
  'DESCRIPTOR' : _CECON_GETINVENTORYITEMSWITHDESCRIPTIONS_RESPONSE,
  '__module__' : 'steammessages_econ_pb2'
  # @@protoc_insertion_point(class_scope:CEcon_GetInventoryItemsWithDescriptions_Response)
  })
_sym_db.RegisterMessage(CEcon_GetInventoryItemsWithDescriptions_Response)

CEcon_GetTradeOfferAccessToken_Request = _reflection.GeneratedProtocolMessageType('CEcon_GetTradeOfferAccessToken_Request', (_message.Message,), {
  'DESCRIPTOR' : _CECON_GETTRADEOFFERACCESSTOKEN_REQUEST,
  '__module__' : 'steammessages_econ_pb2'
  # @@protoc_insertion_point(class_scope:CEcon_GetTradeOfferAccessToken_Request)
  })
_sym_db.RegisterMessage(CEcon_GetTradeOfferAccessToken_Request)

CEcon_GetTradeOfferAccessToken_Response = _reflection.GeneratedProtocolMessageType('CEcon_GetTradeOfferAccessToken_Response', (_message.Message,), {
  'DESCRIPTOR' : _CECON_GETTRADEOFFERACCESSTOKEN_RESPONSE,
  '__module__' : 'steammessages_econ_pb2'
  # @@protoc_insertion_point(class_scope:CEcon_GetTradeOfferAccessToken_Response)
  })
_sym_db.RegisterMessage(CEcon_GetTradeOfferAccessToken_Response)

CEcon_ClientGetItemShopOverlayAuthURL_Request = _reflection.GeneratedProtocolMessageType('CEcon_ClientGetItemShopOverlayAuthURL_Request', (_message.Message,), {
  'DESCRIPTOR' : _CECON_CLIENTGETITEMSHOPOVERLAYAUTHURL_REQUEST,
  '__module__' : 'steammessages_econ_pb2'
  # @@protoc_insertion_point(class_scope:CEcon_ClientGetItemShopOverlayAuthURL_Request)
  })
_sym_db.RegisterMessage(CEcon_ClientGetItemShopOverlayAuthURL_Request)

CEcon_ClientGetItemShopOverlayAuthURL_Response = _reflection.GeneratedProtocolMessageType('CEcon_ClientGetItemShopOverlayAuthURL_Response', (_message.Message,), {
  'DESCRIPTOR' : _CECON_CLIENTGETITEMSHOPOVERLAYAUTHURL_RESPONSE,
  '__module__' : 'steammessages_econ_pb2'
  # @@protoc_insertion_point(class_scope:CEcon_ClientGetItemShopOverlayAuthURL_Response)
  })
_sym_db.RegisterMessage(CEcon_ClientGetItemShopOverlayAuthURL_Response)

CEcon_GetAssetClassInfo_Request = _reflection.GeneratedProtocolMessageType('CEcon_GetAssetClassInfo_Request', (_message.Message,), {

  'Class' : _reflection.GeneratedProtocolMessageType('Class', (_message.Message,), {
    'DESCRIPTOR' : _CECON_GETASSETCLASSINFO_REQUEST_CLASS,
    '__module__' : 'steammessages_econ_pb2'
    # @@protoc_insertion_point(class_scope:CEcon_GetAssetClassInfo_Request.Class)
    })
  ,
  'DESCRIPTOR' : _CECON_GETASSETCLASSINFO_REQUEST,
  '__module__' : 'steammessages_econ_pb2'
  # @@protoc_insertion_point(class_scope:CEcon_GetAssetClassInfo_Request)
  })
_sym_db.RegisterMessage(CEcon_GetAssetClassInfo_Request)
_sym_db.RegisterMessage(CEcon_GetAssetClassInfo_Request.Class)

CEcon_GetAssetClassInfo_Response = _reflection.GeneratedProtocolMessageType('CEcon_GetAssetClassInfo_Response', (_message.Message,), {
  'DESCRIPTOR' : _CECON_GETASSETCLASSINFO_RESPONSE,
  '__module__' : 'steammessages_econ_pb2'
  # @@protoc_insertion_point(class_scope:CEcon_GetAssetClassInfo_Response)
  })
_sym_db.RegisterMessage(CEcon_GetAssetClassInfo_Response)


DESCRIPTOR._options = None
_CECON_ASSET.fields_by_name['currencyid']._options = None
_CECONITEM_TAG.fields_by_name['appid']._options = None
_CECONITEM_TAG.fields_by_name['category']._options = None
_CECONITEM_TAG.fields_by_name['internal_name']._options = None
_CECONITEM_TAG.fields_by_name['localized_category_name']._options = None
_CECONITEM_TAG.fields_by_name['localized_tag_name']._options = None
_CECONITEM_TAG.fields_by_name['color']._options = None
_CECON_GETINVENTORYITEMSWITHDESCRIPTIONS_RESPONSE.fields_by_name['missing_assets']._options = None

_ECON = _descriptor.ServiceDescriptor(
  name='Econ',
  full_name='Econ',
  file=DESCRIPTOR,
  index=0,
  serialized_options=b'\202\265\030;A service that provides communication with the econ servers',
  create_key=_descriptor._internal_create_key,
  serialized_start=3008,
  serialized_end=3830,
  methods=[
  _descriptor.MethodDescriptor(
    name='GetInventoryItemsWithDescriptions',
    full_name='Econ.GetInventoryItemsWithDescriptions',
    index=0,
    containing_service=None,
    input_type=_CECON_GETINVENTORYITEMSWITHDESCRIPTIONS_REQUEST,
    output_type=_CECON_GETINVENTORYITEMSWITHDESCRIPTIONS_RESPONSE,
    serialized_options=b'\202\265\030CGets a set of items from a users inventory, along with descriptions',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetTradeOfferAccessToken',
    full_name='Econ.GetTradeOfferAccessToken',
    index=1,
    containing_service=None,
    input_type=_CECON_GETTRADEOFFERACCESSTOKEN_REQUEST,
    output_type=_CECON_GETTRADEOFFERACCESSTOKEN_RESPONSE,
    serialized_options=b'\202\265\030\'Get the user\'s trade offer access token',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ClientGetItemShopOverlayAuthURL',
    full_name='Econ.ClientGetItemShopOverlayAuthURL',
    index=2,
    containing_service=None,
    input_type=_CECON_CLIENTGETITEMSHOPOVERLAYAUTHURL_REQUEST,
    output_type=_CECON_CLIENTGETITEMSHOPOVERLAYAUTHURL_RESPONSE,
    serialized_options=b'\202\265\030QGenerates a URL which sets a secure cookie for in-game-browser itemshop purchases',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetAssetClassInfo',
    full_name='Econ.GetAssetClassInfo',
    index=3,
    containing_service=None,
    input_type=_CECON_GETASSETCLASSINFO_REQUEST,
    output_type=_CECON_GETASSETCLASSINFO_RESPONSE,
    serialized_options=b'\202\265\030AReturns description information about the passed in asset classes',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_ECON)

DESCRIPTOR.services_by_name['Econ'] = _ECON

Econ = service_reflection.GeneratedServiceType('Econ', (_service.Service,), dict(
  DESCRIPTOR = _ECON,
  __module__ = 'steammessages_econ_pb2'
  ))

Econ_Stub = service_reflection.GeneratedServiceStubType('Econ_Stub', (Econ,), dict(
  DESCRIPTOR = _ECON,
  __module__ = 'steammessages_econ_pb2'
  ))


# @@protoc_insertion_point(module_scope)



"""
:class:`GameCoordinator` is used to proxy messages from/to GC.
It takes care of the encapsulation details, but on its own is not
enough to communicate with a given GC.

Example implementation of Dota 2 GC client with inheritance.

.. code:: python

    import myDotaModule
    from steam.client import SteamClient
    from steam.core.msg import GCMsgHdrProto
    from steam.client.gc import GameCoordinator

    class ExampleDotaClient(GameCoordinator):
        def __init__(self, steam):
            GameCoordinator.__init__(self, steam, 570)

        def _process_gc_message(self, emsg, header, body):
            if emsg == 4004: # EMsgGCClientWelcome
                message = myDotaModule.gcsdk_gcmessages_pb2.CMsgClientWelcome()
                message.ParseFromString(body)
                print message

        def send_hello(self):
            header = GCMsgHdrProto(4006)  # EMsgGCClientHello
            body = myDotaModule.gcsdk_gcmessages_pb2.CMsgClientHello()
            self.send(header, body.SerializeToString())

    client = SteamClient()
    dota = ExampleDotaClient(client)

    client.login()
    client.games_played([570])
    dota.send_hello()

The above code assumes that we have a ``myDotaModule`` that contains the appropriate
protobufs needed to (de)serialize message for communication with GC.
"""
import logging
import gevent
from eventemitter import EventEmitter
from steam.utils.proto import set_proto_bit, clear_proto_bit, is_proto
from steam.enums.emsg import EMsg
from steam.enums import EResult
from steam.core.msg import GCMsgHdr, GCMsgHdrProto, MsgProto
from steam.client import SteamClient


class GameCoordinator(EventEmitter):
    """
    ``GameCoordinator`` is used to proxy messages from/to GC

    :param steam_client: steam client instance
    :type steam_client: :class:`steam.client.SteamClient`
    :param app_id: app id of the application
    :type app_id: :class:`int`

    Incoming messages are emitted as events using their ``EMsg`` as an event identifier.

    :param header: message header
    :type header: :class:`steam.core.msg.GCMsgHdr`
    :param body: raw message body
    :type body: :class:`bytes`
    """

    def __init__(self, steam_client, app_id):
        if not isinstance(steam_client, SteamClient):
            raise ValueError("Expected an instance of SteamClient as first argument")

        self.steam = steam_client
        self.app_id = app_id
        self._LOG = logging.getLogger("GC(appid:%d)" % app_id)

        # listen for GC messages
        self.steam.on(EMsg.ClientFromGC, self._handle_from_gc)

    def emit(self, event, *args):
        if event is not None:
            self._LOG.debug("Emit event: %s" % repr(event))
        EventEmitter.emit(self, event, *args)

    def send(self, header, body):
        """
        Send a message to GC

        :param header: message header
        :type header: :class:`steam.core.msg.GCMsgHdr`
        :param body: serialized body of the message
        :type body: :class:`bytes`
        """
        message = MsgProto(EMsg.ClientToGC)
        message.header.routing_appid = self.app_id
        message.body.appid = self.app_id
        message.body.msgtype = (set_proto_bit(header.msg)
                                if header.proto
                                else header.msg
                                )
        message.body.payload = header.serialize() + body
        self.steam.send(message)

    def _handle_from_gc(self, msg):
        if msg.body.appid != self.app_id:
            return

        emsg = msg.body.msgtype

        if is_proto(emsg):
            header = GCMsgHdrProto(emsg, msg.body.payload)
            header_size = GCMsgHdrProto._size + header.headerLength
        else:
            header = GCMsgHdr(emsg, msg.body.payload)
            header_size = GCMsgHdr._size

        body = msg.body.payload[header_size:]

        self._process_gc_message(clear_proto_bit(emsg), header, body)

    def _process_gc_message(self, emsg, header, body):
        self.emit(emsg, header, body)




import six
from types import GeneratorType as _GeneratorType
from google.protobuf.message import Message as _ProtoMessageType


if six.PY2:
    _list_types = list, xrange, _GeneratorType
else:
    _list_types = list, range, _GeneratorType, map, filter

protobuf_mask = 0x80000000


def is_proto(emsg):
    """
    :param emsg: emsg number
    :type emsg: int
    :return: True or False
    :rtype: bool
    """
    return (int(emsg) & protobuf_mask) > 0

def set_proto_bit(emsg):
    """
    :param emsg: emsg number
    :type emsg: int
    :return: emsg with proto bit set
    :rtype: int
    """
    return int(emsg) | protobuf_mask

def clear_proto_bit(emsg):
    """
    :param emsg: emsg number
    :type emsg: int
    :return: emsg with proto bit removed
    :rtype: int
    """
    return int(emsg) & ~protobuf_mask

def proto_to_dict(message):
    """Converts protobuf message instance to dict

    :param message: protobuf message instance
    :return: parameters and their values
    :rtype: dict
    :raises: :class:`.TypeError` if ``message`` is not a proto message
    """
    if not isinstance(message, _ProtoMessageType):
        raise TypeError("Expected `message` to be a instance of protobuf message")

    data = {}

    for desc, field in message.ListFields():
        if desc.type == desc.TYPE_MESSAGE:
            if desc.label == desc.LABEL_REPEATED:
                data[desc.name] = list(map(proto_to_dict, field))
            else:
                data[desc.name] = proto_to_dict(field)
        else:
            data[desc.name] = list(field) if desc.label == desc.LABEL_REPEATED else field

    return data

def proto_fill_from_dict(message, data, clear=True):
    """Fills protobuf message parameters inplace from a :class:`dict`

    :param message: protobuf message instance
    :param data: parameters and values
    :type data: dict
    :param clear: whether clear exisiting values
    :type clear: bool
    :return: value of message paramater
    :raises: incorrect types or values will raise
    """
    if not isinstance(message, _ProtoMessageType):
        raise TypeError("Expected `message` to be a instance of protobuf message")
    if not isinstance(data, dict):
        raise TypeError("Expected `data` to be of type `dict`")

    if clear: message.Clear()
    field_descs = message.DESCRIPTOR.fields_by_name

    for key, val in data.items():
        desc = field_descs[key]

        if desc.type == desc.TYPE_MESSAGE:
            if desc.label == desc.LABEL_REPEATED:
                if not isinstance(val, _list_types):
                    raise TypeError("Expected %s to be of type list, got %s" % (repr(key), type(val)))

                list_ref = getattr(message, key)

                # Takes care of overwriting list fields when merging partial data (clear=False)
                if not clear: del list_ref[:]  # clears the list

                for item in val:
                    item_message = getattr(message, key).add()
                    proto_fill_from_dict(item_message, item)
            else:
                if not isinstance(val, dict):
                    raise TypeError("Expected %s to be of type dict, got %s" % (repr(key), type(dict)))

                proto_fill_from_dict(getattr(message, key), val)
        else:
            if isinstance(val, _list_types):
                list_ref = getattr(message, key)
                if not clear: del list_ref[:]  # clears the list
                list_ref.extend(val)
            else:
                setattr(message, key, val)

    return message




from base64 import b64decode
from io import BytesIO
from zipfile import ZipFile, ZIP_DEFLATED, BadZipFile
from struct import pack
from datetime import datetime
from fnmatch import fnmatch
import os.path

from steam.enums import EDepotFileFlag
from steam.core.crypto import symmetric_decrypt
from steam.utils.binary import StructReader
from steam.protobufs.content_manifest_pb2 import (ContentManifestMetadata,
                                                  ContentManifestPayload,
                                                  ContentManifestSignature)


class DepotFile(object):
    def __init__(self, manifest, file_mapping):
        """Depot file

        :param manifest: depot manifest
        :type  manifest: :class:`.DepotManifest`
        :param file_mapping: depot file mapping instance
        :type  file_mapping: ContentManifestPayload.FileMapping
        """
        if not isinstance(manifest, DepotManifest):
            raise TypeError("Expected 'manifest' to be of type DepotManifest")
        if not isinstance(file_mapping, ContentManifestPayload.FileMapping):
            raise TypeError("Expected 'file_mapping' to be of type ContentManifestPayload.FileMapping")

        self.manifest = manifest
        self.file_mapping = file_mapping

    def __repr__(self):
        return "<%s(%s, %s, %s, %s)>" % (
            self.__class__.__name__,
            self.manifest.depot_id,
            self.manifest.gid,
            repr(self.filename),
            'is_directory=True' if self.is_directory else self.size,
            )

    @property
    def filename_raw(self):
        """Filename with null terminator and whitespaces removed

        :type: str
        """
        return self.file_mapping.filename.rstrip('\x00 \n\t')

    @property
    def filename(self):
        """Filename matching the OS

        :type: str
        """
        return os.path.join(*self.filename_raw.split('\\'))
    
    @property
    def linktarget_raw(self):
        """Link target with null terminator and whitespaces removed

        :type: str
        """
        return self.file_mapping.linktarget.rstrip('\x00 \n\t')

    @property
    def linktarget(self):
        """Link target matching the OS

        :type: str
        """
        return os.path.join(*self.linktarget_raw.split('\\'))

    @property
    def size(self):
        """File size in bytes

        :type: int
        """
        return self.file_mapping.size

    @property
    def chunks(self):
        """File chunks instances

        :type: :class:`list` [ContentManifestPayload.FileMapping.ChunkData]
        """
        return self.file_mapping.chunks

    @property
    def flags(self):
        """File flags

        :type: :class:`.EDepotFileFlag`
        """
        return self.file_mapping.flags

    @property
    def is_directory(self):
        """:type: bool"""
        return self.flags & EDepotFileFlag.Directory > 0

    @property
    def is_symlink(self):
        """:type: bool"""
        return not not self.file_mapping.linktarget

    @property
    def is_file(self):
        """:type: bool"""
        return not self.is_directory and not self.is_symlink

    @property
    def is_executable(self):
        """:type: bool"""
        return self.flags & EDepotFileFlag.Executable > 0


class DepotManifest(object):
    DepotFileClass = DepotFile
    PROTOBUF_PAYLOAD_MAGIC = 0x71F617D0
    PROTOBUF_METADATA_MAGIC = 0x1F4812BE
    PROTOBUF_SIGNATURE_MAGIC = 0x1B81B817
    PROTOBUF_ENDOFMANIFEST_MAGIC = 0x32C415AB

    def __init__(self, data=None):
        """Represents depot manifest

        :param data: manifest data
        :type  data: bytes
        """
        self.metadata = ContentManifestMetadata()
        self.payload = ContentManifestPayload()
        self.signature = ContentManifestSignature()

        if data:
            self.deserialize(data)

    def __repr__(self):
        params = ', '.join([
                    "depot_id=" + str(self.depot_id),
                    "gid=" + str(self.gid),
                    "creation_time=" + repr(
                        datetime.utcfromtimestamp(self.metadata.creation_time).isoformat().replace('T', ' ')
                        ),
                    ])

        if self.metadata.filenames_encrypted:
            params += ', filenames_encrypted=True'

        return "<%s(%s)>" % (
            self.__class__.__name__,
            params,
            )

    @property
    def depot_id(self):
        """:type: int"""
        return self.metadata.depot_id

    @property
    def gid(self):
        """:type: int"""
        return self.metadata.gid_manifest

    @property
    def creation_time(self):
        """:type: int"""
        return self.metadata.creation_time

    @property
    def size_original(self):
        """:type: int"""
        return self.metadata.cb_disk_original

    @property
    def size_compressed(self):
        """:type: int"""
        return self.metadata.cb_disk_compressed

    @property
    def filenames_encrypted(self):
        """:type: bool"""
        return self.metadata.filenames_encrypted

    def decrypt_filenames(self, depot_key):
        """Decrypt all filenames in the manifest

        :param depot_key: depot key
        :type  depot_key: bytes
        :raises: :class:`RuntimeError`
        """
        if not self.metadata.filenames_encrypted:
            return

        try:
            for m in self.payload.mappings:
                m.filename = symmetric_decrypt(b64decode(m.filename), depot_key)

                if m.linktarget:
                    m.linktarget = symmetric_decrypt(b64decode(m.linktarget), depot_key)
        except Exception:
            raise RuntimeError("Unable to decrypt filename for depot manifest")

        self.metadata.filenames_encrypted = False

    def deserialize(self, data):
        """Deserialize a manifest (compressed or uncompressed)

        :param data: manifest data
        :type  data: bytes
        """
        try:
            with ZipFile(BytesIO(data)) as zf:
                data = zf.read(zf.filelist[0])
        except BadZipFile:
            pass

        data = StructReader(data)

        magic, length = data.unpack('<II')

        if magic != DepotManifest.PROTOBUF_PAYLOAD_MAGIC:
            raise Exception("Expecting protobuf payload")

        self.payload = ContentManifestPayload()
        self.payload.ParseFromString(data.read(length))

        magic, length = data.unpack('<II')

        if magic != DepotManifest.PROTOBUF_METADATA_MAGIC:
            raise Exception("Expecting protobuf metadata")

        self.metadata = ContentManifestMetadata()
        self.metadata.ParseFromString(data.read(length))

        magic, length = data.unpack('<II')

        if magic != DepotManifest.PROTOBUF_SIGNATURE_MAGIC:
            raise Exception("Expecting protobuf signature")

        self.signature = ContentManifestSignature()
        self.signature.ParseFromString(data.read(length))

        magic, = data.unpack('<I')

        if magic != DepotManifest.PROTOBUF_ENDOFMANIFEST_MAGIC:
            raise Exception("Expecting end of manifest")

    def serialize(self, compress=True):
        """Serialize manifest

        :param compress: wether the output should be Zip compressed
        :type  compress: bytes
        """
        data = BytesIO()

        part = self.payload.SerializeToString()
        data.write(pack('<II', DepotManifest.PROTOBUF_PAYLOAD_MAGIC, len(part)))
        data.write(part)

        part = self.metadata.SerializeToString()
        data.write(pack('<II', DepotManifest.PROTOBUF_METADATA_MAGIC, len(part)))
        data.write(part)

        part = self.signature.SerializeToString()
        data.write(pack('<II', DepotManifest.PROTOBUF_SIGNATURE_MAGIC, len(part)))
        data.write(part)

        data.write(pack('<I', DepotManifest.PROTOBUF_ENDOFMANIFEST_MAGIC))

        if compress:
            zbuff = BytesIO()
            with ZipFile(zbuff, 'w', ZIP_DEFLATED) as zf:
                zf.writestr('z', data.getvalue())

            return zbuff.getvalue()
        else:
            return data.getvalue()

    def __iter__(self):
        if not self.filenames_encrypted:
            for mapping in self.payload.mappings:
                yield self.DepotFileClass(self, mapping)

    def iter_files(self, pattern=None):
        """
        :param pattern: unix shell wildcard pattern, see :func:`.fnmatch`
        :type  pattern: str
        """
        if not self.filenames_encrypted:
            for mapping in self.payload.mappings:
                if (pattern is not None
                   and not fnmatch(mapping.filename.rstrip('\x00 \n\t'), pattern)):
                    continue
                yield self.DepotFileClass(self, mapping)

    def __len__(self):
        return len(self.payload.mappings)


